package com.dgtly.system.service.impl;

import java.util.List;
import com.dgtly.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.dgtly.system.mapper.AlertConfigurationMapper;
import com.dgtly.system.domain.AlertConfiguration;
import com.dgtly.system.service.IAlertConfigurationService;
import com.dgtly.common.core.text.Convert;

/**
 * 弹框配置Service业务层处理
 * 
 * @author chenyn
 * @date 2023-06-13
 */
@Service
public class AlertConfigurationServiceImpl implements IAlertConfigurationService 
{
    @Autowired
    private AlertConfigurationMapper alertConfigurationMapper;

    /**
     * 查询弹框配置
     * 
     * @param alertId 弹框配置ID
     * @return 弹框配置
     */
    @Override
    public AlertConfiguration selectAlertConfigurationById(Long alertId)
    {
        return alertConfigurationMapper.selectAlertConfigurationById(alertId);
    }

    @Override
    public AlertConfiguration selectAlertConfigurationByAlertStatus(int alertStatus) {
        return alertConfigurationMapper.selectAlertConfigurationByAlertStatus(alertStatus);
    }

    /**
     * 查询弹框配置列表
     * 
     * @param alertConfiguration 弹框配置
     * @return 弹框配置
     */
    @Override
    public List<AlertConfiguration> selectAlertConfigurationList(AlertConfiguration alertConfiguration)
    {
        return alertConfigurationMapper.selectAlertConfigurationList(alertConfiguration);
    }

    @Override
    public int selectAlertConfigurationListFilter() {
        return alertConfigurationMapper.selectAlertConfigurationListFilter();
    }

    /**
     * 新增弹框配置
     * 
     * @param alertConfiguration 弹框配置
     * @return 结果
     */
    @Override
    public int insertAlertConfiguration(AlertConfiguration alertConfiguration)
    {
        return alertConfigurationMapper.insertAlertConfiguration(alertConfiguration);
    }

    /**
     * 修改弹框配置
     * 
     * @param alertConfiguration 弹框配置
     * @return 结果
     */
    @Override
    public int updateAlertConfiguration(AlertConfiguration alertConfiguration)
    {
        return alertConfigurationMapper.updateAlertConfiguration(alertConfiguration);
    }

    /**
     * 删除弹框配置对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteAlertConfigurationByIds(String ids)
    {
        return alertConfigurationMapper.deleteAlertConfigurationByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除弹框配置信息
     * 
     * @param alertId 弹框配置ID
     * @return 结果
     */
    @Override
    public int deleteAlertConfigurationById(Long alertId)
    {
        return alertConfigurationMapper.deleteAlertConfigurationById(alertId);
    }
}
